# awkward-1.0

Development of awkward 1.0, to replace [scikit-hep/awkward-array](https://github.com/scikit-hep/awkward-array) in 2020.

   * [Motivation and requirements](https://docs.google.com/document/d/1lj8ARTKV1_hqGTh0W_f01S6SsmpzZAXz9qqqWnEB3j4/edit?usp=sharing)
   * [Design document](https://docs.google.com/document/d/17xSS6XOoW4f5YSu0t4yOyEEVB_zlMgCplSSeCJ-Bt_s/edit?usp=sharing)
